# Vizro Vizro is a toolkit for creating modular data visualization applications.

##### Get Started

New to Vizro? Tutorials to get started and to explore the key features.

##### How-to Guides

Step-by-step instructions on how to use Vizro features.

##### API Reference

Detailed reference of the Vizro API and our pydantic models.

##### Explanation

Background information and answers to your "why..?" questions.

##### Contribute

Contribution guidelines and all our current and past contributors.